package com.logicbig.example;

import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.web.servlet.*;
import org.springframework.web.servlet.config.annotation.EnableWebMvc;
import org.springframework.web.servlet.handler.*;
import org.springframework.web.servlet.mvc.method.annotation.ExceptionHandlerExceptionResolver;
import org.springframework.web.servlet.view.InternalResourceViewResolver;

import java.util.Arrays;

@EnableWebMvc
@ComponentScan("com.logicbig.example")
public class AppConfig {
    
    @Bean(DispatcherServlet.HANDLER_EXCEPTION_RESOLVER_BEAN_NAME)
    HandlerExceptionResolver customExceptionResolver (ApplicationContext ac) {

        ExceptionHandlerExceptionResolver e = new ExceptionHandlerExceptionResolver();
        e.setApplicationContext(ac);
        e.afterPropertiesSet();

        SimpleMappingExceptionResolver s = new SimpleMappingExceptionResolver();
        s.setDefaultErrorView("default-error");
        s.setDefaultStatusCode(HttpStatus.INTERNAL_SERVER_ERROR.value());

        HandlerExceptionResolverComposite c = new HandlerExceptionResolverComposite();
        c.setExceptionResolvers(Arrays.asList(e, s));
        return c;
    }
    
    @Bean
    public ViewResolver viewResolver () {
        InternalResourceViewResolver viewResolver =
                  new InternalResourceViewResolver();
        viewResolver.setPrefix("/WEB-INF/views/");
        viewResolver.setSuffix(".jsp");
        return viewResolver;
    }
}